@@ -1,4 +1,4 @@
-__version__ = '0.0.26'
+__version__ = '0.0.27'
 
 DB_VERSION = 1
 
@@ -96,7 +96,11 @@ class YEDB():
         else:
             data = json.loads(r.text)
         try:
-            raise RuntimeError(data['error']['message'])
+            error_code = data['error']['code']
+            if error_code == 32001:
+                raise KeyError(data['error']['message'])
+            else:
+                raise RuntimeError(data['error']['message'])
         except KeyError:
             return data['result']
 
